.. This file should at least contain the root `toctree` directive.

==========================================
Tarbell: Simple static sites for newsrooms
==========================================
*Build stories, not websites.*

Tarbell makes it simple to put your work on the web, whether you’re a team of one or
a dozen. With Tarbell, you can collaboratively build beautiful websites and publish them with ease.

Tarbell makes use of familiar, flexible tools to take the magic (and frustration) out
of publishing to the web. Google spreadsheets handle content management, so
changes to your stories are easy to make without touching a line of code. Step-by-step
prompts help you set up and configure your project, so that publishing it is a breeze.

New here? Read the `Tarbell tutorial <tutorial.html>`_ or `install and configure Tarbell <install.rst>`_ to get started.

Need help? `File a ticket tagged "support" in Github <https://github.com/newsapps/flask-tarbell/issues/new>`_.

*Tarbell is named after Ida Tarbell, a distinguished muckraking journalist whose
1904 The History of the Standard Oil Company is a masterpiece of investigative
reporting.* `Read more about her on Wikipedia <http://en.wikipedia.org/wiki/Ida_Tarbell>`_.

Anatomy of a Tarbell project
============================

Tarbell projects are made up of four pieces:

* The `core Tarbell library <https://github.com/newsapps/flask-tarbell>`_, installed when you run `pip install tarbell`

* A Tarbell blueprint directory (included in the core library)

* Your project template files

* A Google spreadsheet (optional)

Using Tarbell
=============

.. toctree::
   tutorial
   install
   create
   build
   google_spreadsheets
   publish
   managingprojects

Reference
=========

.. toctree::
    hooks
    reference
    configuring
    contributing

